<?php
/**************************************************
  Coppermine Plugin - Sitemap Generator
  *************************************************
  Copyright (c) 2011 Allyson Moisan
  *************************************************
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License version 3
  as published by the Free Software Foundation.
***************************************************/

if (!defined('IN_COPPERMINE')) die('Not in Coppermine...');

/*
  * Returns the created directory or false.
  *
  * @param Directory to create (String)
  * @param Directory permissions to use (Integer)
  * @return Created directory or false;
  */
		
function mkDirFix ($path, $perms) {
	global $CONFIG;
	
	DEFINE ('FTP_SERVER', $CONFIG['plugin_sitemap_gen_server']);
	DEFINE ('FTP_USER', $CONFIG['plugin_sitemap_gen_user']);
	DEFINE ('FTP_PASS', $CONFIG['plugin_sitemap_gen_pass']);
	DEFINE ('FTP_PATH', $CONFIG['plugin_sitemap_gen_path']);
	
	$conn_id = ftp_connect(FTP_SERVER);
	$currPath = FTP_PATH . $path;
	if(!$conn_id) {
		return false;
	}
			
	if (ftp_login($conn_id, FTP_USER, FTP_PASS)) {
       	if(!ftp_mkdir($conn_id, $currPath)) {
			ftp_close($conn_id);
			return false;
		}
		if(!ftp_chmod($conn_id, $perms, $currPath)) {
			ftp_close($conn_id);
			return false;
		}
	}
				
	$endpath = 'init';
	if(!ftp_chdir($conn_id, $currPath))
		$endpath = 'empty';
	else $endpath = ftp_pwd($conn_id);
				
	ftp_close($conn_id);
	return $endPath;	
}


/*
  * Returns true if file was created or false on error.
  *
  * @param Contents to be written to file (String)
  * @param Path of file to create (String)
  * @return Creation state (Boolean);
  */
  
function mkFileFix ($filecontents, $filepath) {
	global $CONFIG;
	
	DEFINE ('FTP_SERVER', $CONFIG['plugin_sitemap_gen_server']);
	DEFINE ('FTP_USER', $CONFIG['plugin_sitemap_gen_user']);
	DEFINE ('FTP_PASS', $CONFIG['plugin_sitemap_gen_pass']);
	DEFINE ('FTP_PATH', $CONFIG['plugin_sitemap_gen_path']);
	
	$conn_id = ftp_connect(FTP_SERVER);
	if(!$conn_id) {
		return false;
	}		
	
	if (ftp_login($conn_id, FTP_USER, FTP_PASS)) {
		
		$tempHandle = fopen('php://temp', 'r+');
		fwrite($tempHandle, $filecontents);
		rewind($tempHandle);       

		if(!$success = ftp_fput($conn_id, FTP_PATH . $filepath, $tempHandle, FTP_ASCII)) {
			fclose('php://temp');
			ftp_close($conn_id);
			return false;
		}
		
		fclose('php://temp');
	}
	
	ftp_close($conn_id);
	return true;
}

/*
  * Returns true if directory was removed, false on error.
  *
  * @param Directory to remove (String)
  * @return Removal state (Boolean);
  */
		
function rmDirFix ($path) {
	global $CONFIG;
	
	DEFINE ('FTP_SERVER', $CONFIG['plugin_sitemap_gen_server']);
	DEFINE ('FTP_USER', $CONFIG['plugin_sitemap_gen_user']);
	DEFINE ('FTP_PASS', $CONFIG['plugin_sitemap_gen_pass']);
	DEFINE ('FTP_PATH', $CONFIG['plugin_sitemap_gen_path']);
	
	$conn_id = ftp_connect(FTP_SERVER);
	$currPath = FTP_PATH . $path;
	if(!$conn_id) {
		return false;
	}
			
	if (ftp_login($conn_id, FTP_USER, FTP_PASS)) {
       	if(!ftp_rmdir($conn_id, $currPath)) {
			ftp_close($conn_id);
			return false;
		}
		ftp_close($conn_id);
		return true;
	}
	
	ftp_close($conn_id);
	return false;
}

/*
  * Returns true if file was deleted, false on error.
  *
  * @param Path of file to delete (String)
  * @return Removal state (Boolean);
  */
  
function rmFileFix ($filepath) {
	global $CONFIG;
	
	DEFINE ('FTP_SERVER', $CONFIG['plugin_sitemap_gen_server']);
	DEFINE ('FTP_USER', $CONFIG['plugin_sitemap_gen_user']);
	DEFINE ('FTP_PASS', $CONFIG['plugin_sitemap_gen_pass']);
	DEFINE ('FTP_PATH', $CONFIG['plugin_sitemap_gen_path']);
	
	$conn_id = ftp_connect(FTP_SERVER);
	if(!$conn_id) {
		return false;
	}	
	
	if (ftp_login($conn_id, FTP_USER, FTP_PASS)) {
 		if (!ftp_delete($conn_id, FTP_PATH . $filepath)) {
			ftp_close($conn_id);
			return false;
		}
		ftp_close($conn_id);
		return true;
	}
	
	ftp_close($conn_id);
	return false;
}

/*
  * Returns true if files were deleted, false on error.
  *
  * @param Directory of files to delete (String)
  * @return Removal state (Boolean);
  */
  
function rmDirFiles ($path) {
	if ($handle = opendir($path)) {
    	while (false !== ($file = readdir($handle))) {
    		if ($file != "." && $file != "..") {
        		if(!unlink($path.'/'.$file)) {
					if(!rmFileFix($path.'/'.$file)) {
						closedir($handle);
						return false;
					}
				}
    		}
    	}
    	closedir($handle);
		return true;
	}
	return true;
}

?>